package jalview.gui;

import jalview.jbgui.*;
import jalview.schemes.*;

import jalview.bin.Cache;
import javax.swing.*;
import java.awt.event.ActionEvent;
import java.awt.*;

public class Preferences extends GPreferences
{
  AlignViewport av;
  JInternalFrame frame;
  public Preferences(AlignViewport av)
  {
    this.av = av;
    frame = new JInternalFrame();
    frame.setContentPane(this);
    Desktop.addInternalFrame(frame, "Preferences", 480,350 );


    fullID.setSelected(av.getShowFullId());
    String string = Cache.getProperty("SHOW_FULLSCREEN");
    boolean value = false;
    if(string!=null)
      value =  Boolean.valueOf(string).booleanValue();

    fullScreen.setSelected(value);
    annotations.setSelected(av.getShowAnnotation());

    conservation.setEnabled(av.getShowAnnotation());
    quality.setEnabled(av.getShowAnnotation());
    identity.setEnabled(av.getShowAnnotation());

    conservation.setSelected(av.showConservation);
    quality.setSelected(av.showQuality);
    identity.setSelected(av.showIdentity);

    for(int i=0; i<12; i++)
      colour.addItem( ColourSchemeProperty.getColourName(i) );

    string = Cache.getProperty("DEFAULT_COLOUR");
    if(string!=null)
      colour.setSelectedItem( string );
    else
      colour.setSelectedIndex( 11 );

    String fonts[] = java.awt.GraphicsEnvironment.getLocalGraphicsEnvironment().getAvailableFontFamilyNames();
    for(int i=0; i<fonts.length; i++)
      fontName.addItem(fonts[i]);

    for(int i=1; i<31; i++)
      fontSize.addItem(i+"");

   fontStyle.addItem("plain");
   fontStyle.addItem("bold");
   fontStyle.addItem("italic");

   Font oldFont = av.getFont();
   fontName.setSelectedItem(oldFont.getName());
   fontSize.setSelectedItem(oldFont.getSize() + "");
   fontStyle.setSelectedIndex(oldFont.getStyle());

   gapSymbol.addItem("-");
   gapSymbol.addItem(".");

   gapSymbol.setSelectedItem( av.getGapCharacter()+"" );

  }

  public void ok_actionPerformed(ActionEvent e)
  {
    Cache.setProperty("SHOW_FULL_ID", Boolean.toString( fullID.isSelected() ));
    Cache.setProperty("SHOW_FULLSCREEN", Boolean.toString( fullScreen.isSelected() ));

    Cache.setProperty("SHOW_ANNOTATIONS", Boolean.toString( annotations.isSelected() ));
    Cache.setProperty("SHOW_CONSERVATION", Boolean.toString( conservation.isSelected() ));
    Cache.setProperty("SHOW_QUALITY", Boolean.toString( quality.isSelected() ));
    Cache.setProperty("SHOW_IDENTITY", Boolean.toString( identity.isSelected() ));

    Cache.setProperty("DEFAULT_COLOUR", colour.getSelectedItem().toString() );
    Cache.setProperty("GAP_SYMBOL", gapSymbol.getSelectedItem().toString());

    Cache.setProperty("FONT_NAME", fontName.getSelectedItem().toString());
    Cache.setProperty("FONT_STYLE", fontStyle.getSelectedIndex()+"");
    Cache.setProperty("FONT_SIZE", fontSize.getSelectedItem().toString());

    try    {
      frame.setClosed(true);
    }    catch (Exception ex)  {}

    av.updateFromPreferences();

    repaint();

  }

  public void cancel_actionPerformed(ActionEvent e)
  {
    try{
      frame.setClosed(true);
    }catch(Exception ex){}
  }

  public void annotations_actionPerformed(ActionEvent e)
  {
    conservation.setEnabled(annotations.isSelected());
    quality.setEnabled(annotations.isSelected());
    identity.setEnabled(annotations.isSelected());
  }

}
